==> haskell-test-framework-quickcheck2-0.3.0.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-CDuUzUYSon17K6J0yuJi6B
key: test-framework-quickcheck2-0.3.0.5-CDuUzUYSon17K6J0yuJi6B
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: b044abe6c5e058b7ea1825e580796973
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-CDuUzUYSon17K6J0yuJi6B
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-KO57kWdke3eEL9xLOoYXmM
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-9Sml4LQFhH1G3ClAa5XZpF
key: test-framework-quickcheck2-0.3.0.5-9Sml4LQFhH1G3ClAa5XZpF
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: f85e11b9a24184d8ae4c973127126052
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.3/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-9Sml4LQFhH1G3ClAa5XZpF
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-Bt2cnRgWAY3QQnnHA1ys2
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
